![alt text](https://raw.githubusercontent.com/kyunghoon-han/Tihi_spectral_fitter/688758941fd63fb8998e23d9e3ef9c84c95aecbb/logo_small.png)

# Peak finder GUI tool for chemical or biological signals

## Installation  of the required libraries
One simply needs to run the following to install the required libraries.
```
pip install -r requirements
```
If `pip` is not installed on your machine, you can run either
```
python get-pip.py
```
or
```
python -m ensurepip --upgrade
```
on your machine.
